#!/etc/opt/openit/perl


use strict;
use warnings;
use Getopt::Long;


my $opt_debug;
my $opt_verbose;
my $opt_help;


unless ( GetOptions("help" => \ $opt_help,
         "debug"           => \ $opt_debug,
         "verbose"         => \ $opt_verbose
)) {
    &print_usage;
}

my $configdir = &get_configuration_dir();

&_fix_sti_sample( "$configdir/Components/licpoll.xml" );

sub _fix_sti_sample {
	my ($filter) = @_;
	open(FILE, $filter) || die "Unable to read filter file '$filter'";
    my @lines = <FILE>;
	close(FILE);
	&DEBUG ( "Reading file $filter" );
	my $ind = 0;
	my $line = "";

	
	while(1) {
		
		if ( isEmpty( $lines[$ind] ) ) {
			next;
		}
		
		if ( $lines[$ind] =~ /sti-sample/ ) {
			last;
		}
		++$ind;
	}
	
	while(1) {
		
		if ( isEmpty( $lines[$ind] ) ) {
			next;
		}
		
		if ( $lines[$ind] =~ /STI license file/ ) {
			last;
		}
		++$ind;
	}
	
	++$ind;
	
	$lines[$ind] =~ s/Value type="String"/Value type="FileName"/;
	
	&_save_config( $filter, @lines );

}


sub _save_config
{
	
	my ( $cfg, @lines ) = @_; 
	&create_backup($cfg);
	open(OUT, ">$cfg") || die "Unable to overwrite filter file '$cfg'";
    print OUT @lines;
    close(OUT);
}

sub create_backup 
{
	my ($filter) = @_;
	&DEBUG ( "Creating $filter backup " );
	my $new = "$filter.new";
    my $old = "$filter.2048";

    open(FILE, $filter) || die "Unable to read filter file '$filter'";
    my @lines = <FILE>;
    close(FILE);
	
	open(OUT, ">$old") || die "Unable to create backup file '$old'";
    print OUT @lines;
    close(OUT);
}


sub get_configuration_dir()
{
	my $configdir;
	if ($^O eq 'MSWin32' )	{
		my $cmd = `openit_freemould --script installation_info.oms`;
		chomp $cmd;	
		$configdir =$cmd . "Configuration"
	}
	else {
		$configdir = `. /tmp/openit-cfg-shenv && echo \$CONFIG_DIR`;
	}
	chomp $configdir;
	return $configdir;
}
sub DEBUG {
	my ($log) = @_;
	if ( $opt_debug ) {
		print ( "DEBUG: $log\n" );
	}
}

sub isEmpty {
	my ($var) = @_;
	
	if ( ! defined $var && ! length $var ) {
		return 1;
	}
	return 0;
}

sub VERBOSE  {
	my ($log) = @_;
	if ( $opt_verbose ) {
		print ( "-- $log\n" );
	}
}
